---
title: <span class="badge object-type-scalar"></span> ReadsPerSecond
---
# <span class="badge object-type-scalar"></span> ReadsPerSecond

Throughput: reads/sec (rps)

## Definition

```python
# Throughput: reads/sec (rps)
ReadsPerSecond: typing.Literal["rps"] = "rps"
```
